==> tomee-project-8.0.10-source-release.zip: tomee-project-8.0.10/mp-jwt/src/main/java/org/apache/bval/jsr/job/ConstraintValidators.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.bval.jsr.job;

import org.apache.bval.jsr.ConstraintCached;
import org.apache.bval.jsr.descriptor.ConstraintD;

import javax.validation.ConstraintDeclarationException;
import javax.validation.constraintvalidation.ValidationTarget;
import java.lang.annotation.Annotation;

/**
 * This class is necessary as ComputeConstraintValidatorClass is package-scoped and we
 * need it to determine if a constraint can be validated by a specific type, such as JsonWebToken
 *
 * If ComputeConstraintValidatorClass were to become protected or public, the `canValidate` method
 * should be moved and this class should be deleted.
 */
public class ConstraintValidators {

    private final ConstraintCached constraintsCache = new ConstraintCached();

    public <A extends Annotation> boolean canValidate(final ConstraintD<A> descriptor, final Class<?> validatedType) {
        final ComputeConstraintValidatorClass<A> aComputeConstraintValidatorClass = new ComputeConstraintValidatorClass<A>(
                constraintsCache,
                descriptor,
                ValidationTarget.ANNOTATED_ELEMENT,
                validatedType);

        try {
            aComputeConstraintValidatorClass.get();
            return true;
        } catch (ConstraintDeclarationException e) {
            return false;
        }

    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/mp-jwt/src/main/java/org/apache/bval/jsr/job/ConstraintValidators.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.bval.jsr.job;

import org.apache.bval.jsr.ConstraintCached;
import org.apache.bval.jsr.descriptor.ConstraintD;

import jakarta.validation.ConstraintDeclarationException;
import jakarta.validation.constraintvalidation.ValidationTarget;
import java.lang.annotation.Annotation;

/**
 * This class is necessary as ComputeConstraintValidatorClass is package-scoped and we
 * need it to determine if a constraint can be validated by a specific type, such as JsonWebToken
 *
 * If ComputeConstraintValidatorClass were to become protected or public, the `canValidate` method
 * should be moved and this class should be deleted.
 */
public class ConstraintValidators {

    private final ConstraintCached constraintsCache = new ConstraintCached();

    public <A extends Annotation> boolean canValidate(final ConstraintD<A> descriptor, final Class<?> validatedType) {
        final ComputeConstraintValidatorClass<A> aComputeConstraintValidatorClass = new ComputeConstraintValidatorClass<A>(
                constraintsCache,
                descriptor,
                ValidationTarget.ANNOTATED_ELEMENT,
                validatedType);

        try {
            aComputeConstraintValidatorClass.get();
            return true;
        } catch (ConstraintDeclarationException e) {
            return false;
        }

    }
}
